
# pyscal - python Structural Environment Calculator

Complete documentation with examples available [here](https://pyscal.org/).

pyscal3, a completely new pyscal which is faster and can handle a large number of atoms, with a much more user-friendly and intuitive interface. Adds more features such as more structure creation including grain boundaries, selection, and deletion of atoms


## Installation

pyscal3 can be installed directly using conda by the following statement-

```
    conda install -c conda-forge pyscal3
```

**From repository**

pyscal can be built from the repository by-

```
    git clone https://github.com/pyscal/pyscal3.git
    cd pyscal3
    pip install .
```

## Citing the work

If you use pyscal3 in your work, the citation of the [following article](https://joss.theoj.org/papers/10.21105/joss.01824) will be greatly appreciated:

Sarath Menon, Grisell Díaz Leines and Jutta Rogal (2019). pyscal: A python module for structural analysis of atomic environments. Journal of Open Source Software, 4(43), 1824, https://doi.org/10.21105/joss.01824

## Works using pyscal

For a complete list of publications which used pyscal, see [here](https://scholar.google.com/scholar?oi=bibs&hl=en&cites=315020929885190486&as_sdt=5).

